Some useful functions that are helpful in completing Project Euler (projecteuler.net) problems.

# Description

This package contains 10 moduls
* divisors(n): returns a list of divisors of net
* prime_factors(n): returns a list of the prime factors of n
* is_prime(n): check if n is prime
* sieve_of_eratosthenes(n): returns a list of all prime numbers < n
* is_palindrome(n): checks if n is a palindromic numbers
* is_pandigital(n): n is a m-digit pandigital number if it contains all digits 1-m exactly once
* is permutation(a, b): checks if a and b are permutations of each other
* coprime(a, b): check if a and b are coprime
* totient(n): returns Euler's totient functions
* generalized_hamming(x, n): Checks if integer x has no prime factors larger than n

# Installation

```bash
pip install euler_helper
```